IminLabelInfo enum

Label info query types for labelQueryInfo

Inheritance
Available extensions

Values

MODEL → const IminLabelInfo
VERSION → const IminLabelInfo
HEIGHT → const IminLabelInfo
DENSITY → const IminLabelInfo
SPEED → const IminLabelInfo
MODE → const IminLabelInfo
GAP_OFFSET → const IminLabelInfo
NO_PAPER_THRESHOLD → const IminLabelInfo
HAS_PAPER_THRESHOLD → const IminLabelInfo
THRESHOLD_ADJUSTMENT → const IminLabelInfo
ORIGINAL_STATUS → const IminLabelInfo
LABEL_STATUS → const IminLabelInfo
PAPER_STATUS → const IminLabelInfo
HOST_RESULT → const IminLabelInfo
GAP_ERROR → const IminLabelInfo

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<IminLabelInfo>
A constant List of the values in this enum, in order of their declaration.