PrinterStatus enum

Inheritance
Available extensions

Values

initPrinterError → const PrinterStatus
const PrinterStatus('-1', 'Printer initialization failed!')
normal → const PrinterStatus
const PrinterStatus('0', 'Printer is normal')
notPoweredOn → const PrinterStatus
const PrinterStatus('1', 'Printer not connected or powered on!')
notLibraryMatch → const PrinterStatus
const PrinterStatus('2', 'Printer and call library mismatch!')
openPrintHead → const PrinterStatus
const PrinterStatus('3', 'Printer door is open!')
cutterNotReset → const PrinterStatus
const PrinterStatus('4', 'Cutter not reset!')
overHeated → const PrinterStatus
const PrinterStatus('5', 'Printer head overheated!')
blackLabelError → const PrinterStatus
const PrinterStatus('6', 'Black label error!')
notPaperFeed → const PrinterStatus
const PrinterStatus('7', 'Paper missing!')
outOfPaper → const PrinterStatus
const PrinterStatus('8', 'Paper is running out!')
otherError → const PrinterStatus
const PrinterStatus('99', 'Other errors!')

Properties

code String
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getValue(String code) String

Constants

values → const List<PrinterStatus>
A constant List of the values in this enum, in order of their declaration.