IminEscPosTextStyle class

ESC/POS 文本样式(2.0 SDK 专属) 用于 printEscPosText 方法,直接映射 ESC/POS 字体指令

Constructors

IminEscPosTextStyle({int? widthMultiple, int? heightMultiple, bool? bold, bool? italic, bool? antiWhite, int? underline, int? lineSpacing, int? charSpace, IminPrintAlign? align})

Properties

align IminPrintAlign?
对齐方式
getter/setter pair
antiWhite bool?
反白
getter/setter pair
bold bool?
加粗
getter/setter pair
charSpace int?
字符间距
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
heightMultiple int?
字体倍高 1-8
getter/setter pair
italic bool?
斜体
getter/setter pair
lineSpacing int?
行间距
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
underline int?
下划线 0=无 1=单线 2=双线
getter/setter pair
widthMultiple int?
字体倍宽 1-8
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited