IminQrCodeStyle class

Constructors

IminQrCodeStyle({IminPrintAlign? align, int? qrSize, int? leftMargin, IminQrcodeCorrectionLevel? errorCorrectionLevel})

Properties

align ↔ IminPrintAlign?
getter/setter pair
errorCorrectionLevel ↔ IminQrcodeCorrectionLevel?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
leftMargin ↔ int?
getter/setter pair
qrSize ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited